#!/bin/csh

# Define SAC files - headers must be appropriately populated with rough picks
# See below for headers used
#set sacfile = ` cat sac3B.lst `
set sacfile = 19930115110558.G.INU.__.LHT.sac.pik

@ i = 1
while ( $i <= $#sacfile )
#while ( $i <= 1 )
echo $sacfile[$i]
# Find peak times for ScSn and window them
# Calculate dt
# T0 = ScS; T1 = ScS2; ...
sac << FIN >! sac.out
m getscs.mac win 128 f1 0.01 f2 0.04 rec $sacfile[$i]
quit
FIN

# Output
grep dt= sac.out | awk -F= '{print $2}' >! dt.tmp
set scsdt = ` gmtmath dt.tmp -S MEAN = | awk '{print $2}' `
set scsdtse = ` gmtmath dt.tmp -S STD = | awk '{print $2}' `

set scs12dt = ` grep dtind12= sac.out | awk -F= '{print $2}' `
set scs13dt = ` grep dtind13= sac.out | awk -F= '{print $2}' `
set scs23dt = ` grep dtind23= sac.out | awk -F= '{print $2}' `
echo $scs12dt[2] $scs23dt[2] $scs13dt[2]

# Calculate dt* from MTM
matlab -nodesktop -nojvm -nosplash << FIN >! matlab.out
dtmtm
exit
FIN

# Output
set val = ` awk '{printf " %.1f %.1f %.1f %.1f %.1f %.1f\n", $1, $2, $3, $4, $5, $6}' tval.tst `

set scs12mtm = $val[1]
set scs12mtmse = $val[2]
set scs13mtm = $val[5]
set scs13mtmse = $val[6]
set scs23mtm = $val[3]
set scs23mtmse = $val[4]
echo $scs12mtm $scs23mtm $scs13mtm

# Calculate dt* from IF
sac << FIN >! sac.out
m instfreq.mac win 128
quit
FIN

grep IF= sac.out | awk -F= '{print $2}' >! if.tmp
set scsif = ` awk 'NR==1 {print $3, $4}' if.tmp `

awk '{print $1, ( $2 - '$scsif[1]' ), ( $2 - '$scsif[2]' ), ( $3 - '$scsif[2]' )}' if.tmp >! minval.tmp

set scs12if = ` minmax -EL1 minval.tmp | awk '{print $1}' `
set scs13if = ` minmax -EL2 minval.tmp | awk '{print $1}' `
set scs23if = ` minmax -EL3 minval.tmp | awk '{print $1}' `
echo $scs12if $scs23if $scs13if

# Calculate dt* from t-domain ratio
\rm *.xy
sac << FIN >! sac.out
m envfreq.mac win 128
quit
FIN

set scs12td = ` grep rat21= sac.out | awk -F= '{print $2}' `
set scs13td = ` grep rat31= sac.out | awk -F= '{print $2}' `
set scs23td = ` grep rat32= sac.out | awk -F= '{print $2}' `
echo $scs12td[2] $scs23td[2] $scs13td[2]

# Produce plot components
sac << FIN >! sac.out
m plotcomp.mac win 128
quit
FIN

set scsdtstar = ` echo $scs12mtm $scs23mtm $scs13mtm | awk '{print ( ( $1 + $2 + ( $3 / 2 ) ) / 3 )}' `
set scsdtstarse = ` echo $scs12mtmse $scs23mtmse $scs13mtmse | awk '{print ( ( $1 + $2 + ( $3 / 2 ) ) / 3 )}' `

#echo $scsdt >! tval.out
echo $scs12dt[2] >! tval.out
echo $scsdtse >> tval.out
#echo $scsdtstar >> tval.out
echo $scs12if >> tval.out
echo $scsdtstarse >> tval.out

set pref = ` echo $sacfile[$i] | cut -d. -f1-5 `
echo $scs12dt[2] $scsdtse $scs12if $scsdtstarse >! $pref.tval.out

@ i++
end

